Removed hidden args and hipLaunchParm from HIP/HCC path
[ROCm/clr commit: 2184e7f6da]
This commit is contained in:
@@ -23,7 +23,7 @@ THE SOFTWARE.
|
||||
#include "hip/hip_runtime.h"
|
||||
extern texture<float, 2, hipReadModeElementType> tex;
|
||||
|
||||
extern "C" __global__ void tex2dKernel(hipLaunchParm lp, float* outputData, int width, int height) {
|
||||
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
|
||||
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
|
||||
int y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;
|
||||
outputData[y * width + x] = tex2D(tex, x, y);
|
||||
|
||||
@@ -90,7 +90,6 @@ bool runTest(int argc, char** argv) {
|
||||
#ifdef __HIP_PLATFORM_HCC__
|
||||
|
||||
struct {
|
||||
uint32_t _hidden[6]; // genco path + wrapper-gen pass used hidden arguments.
|
||||
void* _Ad;
|
||||
unsigned int _Bd;
|
||||
unsigned int _Cd;
|
||||
|
||||
Fai riferimento in un nuovo problema
Block a user